@@ -23,6 +23,7 @@
 #include "basetransform.h"
 #include "bin.h"
 #include "buffer.h"
+#include "bufferlist.h"
 #include "bus.h"
 #include "caps.h"
 #include "cddabasesrc.h"
@@ -84,6 +85,7 @@
 #include "alsasink.h"
 #include "alsasrc.h"
 #include "audioconvert.h"
+#include "audiorate.h"
 #include "audioresample.h"
 #include "audiotestsrc.h"
 #include "capsfilter.h"
@@ -105,13 +107,17 @@
 #include "giostreamsink.h"
 #include "giostreamsrc.h"
 #include "identity.h"
+#include "inputselector.h"
 #include "multifdsink.h"
 #include "multiqueue.h"
 #include "oggdemux.h"
 #include "oggmux.h"
+#include "outputselector.h"
 #include "playbin2.h"
 #include "playbin.h"
 #include "queue.h"
+#include "queue2.h"
+#include "subtitleoverlay.h"
 #include "tcpclientsink.h"
 #include "tcpclientsrc.h"
 #include "tcpserversink.h"
@@ -125,6 +131,7 @@
 #include "timeoverlay.h"
 #include "typefindelement.h"
 #include "uridecodebin.h"
+#include "valve.h"
 #include "videorate.h"
 #include "videoscale.h"
 #include "videotestsrc.h"
@@ -142,6 +149,7 @@ extern "C"
 //Declarations of the *_get_type() functions:
 
 GType gst_buffer_get_type(void);
+GType gst_buffer_list_get_type(void);
 GType gst_event_get_type(void);
 GType gst_message_get_type(void);
 GType gst_query_get_type(void);
@@ -154,6 +162,7 @@ GType gst_query_get_type(void);
 //Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:
 
 namespace Gst {  class Buffer_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }
+namespace Gst {  class BufferList_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }
 namespace Gst {  class Event_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }
 namespace Gst {  class Message_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }
 namespace Gst {  class Query_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }
@@ -165,12 +174,14 @@ void gst_wrap_init()
 
 // Map gtypes to gstreamermm wrapper-creation functions:
   Gst::wrap_register(gst_buffer_get_type(), &Gst::Buffer_Class::wrap_new);
+  Gst::wrap_register(gst_buffer_list_get_type(), &Gst::BufferList_Class::wrap_new);
   Gst::wrap_register(gst_event_get_type(), &Gst::Event_Class::wrap_new);
   Gst::wrap_register(gst_message_get_type(), &Gst::Message_Class::wrap_new);
   Gst::wrap_register(gst_query_get_type(), &Gst::Query_Class::wrap_new);
 
   // Register the gtkmm gtypes:
   Gst::Buffer::get_type();
+  Gst::BufferList::get_type();
   Gst::Event::get_type();
   Gst::Message::get_type();
   Gst::Query::get_type();
